|Build Status|

Terraform Template Resource Provider
====================================

The Terraform Template provider for Pulumi lets you use Terraform
templates in your cloud programs.

This package is meant for use with the Pulumi CLI. Please visit
`docs.pulumi.com <https://docs.pulumi.com>`__ for installation
instructions.

.. |Build Status| image:: https://travis-ci.com/pulumi/pulumi-terraform-template.svg?token=eHg7Zp5zdDDJfTjY8ejq&branch=master
   :target: https://travis-ci.com/pulumi/pulumi-terraform-template
